pub(crate) fn rewrite_json2_schema(
schema: &SchemaRef,
plans: &HashMap<String, Json2RewritePlan>,
) -> SchemaRefExpand description
Replaces JSON2 physical field types according to the computed rewrite plans.
pub(crate) fn rewrite_json2_schema(
schema: &SchemaRef,
plans: &HashMap<String, Json2RewritePlan>,
) -> SchemaRefReplaces JSON2 physical field types according to the computed rewrite plans.